pub enum Error {
BufferUnderflow {
needed: usize,
available: usize,
},
InvalidData(String),
VarIntTooLarge,
StringTooLong {
len: usize,
max: usize,
},
InvalidUtf8(FromUtf8Error),
Nbt(String),
Context {
context: String,
source: Box<Error>,
},
}Expand description
Errors that can occur during encoding or decoding of Minecraft protocol types.
Variants
BufferUnderflow
InvalidData(String)
VarIntTooLarge
StringTooLong
InvalidUtf8(FromUtf8Error)
Nbt(String)
Context
An error with added context about where it occurred during decoding (e.g., which field or packet was being decoded).
Implementations